pub struct Conversation {
pub username: String,
pub password: String,
pub log: Vec<LogEntry>,
}Expand description
Non-interactive implementation of ConversationHandler
When a PAM module asks for a non-secret string, username
will be returned and when a secret string is asked for,
password will be returned.
All info and error messages will be recorded in log.
Limitations
This is enough to handle many authentication flows non-interactively, but
flows with two-factor-authentication and things like
chauthok() will most definitely fail.
Please also note that UTF-8 encoding is assumed for both username and password, so this handler may fail to authenticate on legacy non-UTF-8 systems when one of the strings contains non-ASCII characters.
Fields
username: StringThe username to use
password: StringThe password to use
log: Vec<LogEntry>All received info/error messages
Implementations
sourceimpl Conversation
impl Conversation
sourcepub const fn new() -> Self
pub const fn new() -> Self
Creates a new CLI conversation handler
If username isn’t manually set to a non-empty
string, it will be automatically set to the Contexts default
username on context initialization.
sourcepub fn with_credentials(
username: impl Into<String>,
password: impl Into<String>,
) -> Self
pub fn with_credentials( username: impl Into<String>, password: impl Into<String>, ) -> Self
Creatse a new CLI conversation handler with preset credentials
sourcepub fn errors(&self) -> impl Iterator<Item = &CString> + FusedIterator
pub fn errors(&self) -> impl Iterator<Item = &CString> + FusedIterator
Lists only errors from the log
sourcepub fn infos(&self) -> impl Iterator<Item = &CString> + FusedIterator
pub fn infos(&self) -> impl Iterator<Item = &CString> + FusedIterator
Lists only info messages from the log