EnvList

Struct EnvList 

pub struct EnvList(/* private fields */);
A PAM environment list

The PAM environment represents the contents of the regular environment variables of the authenticated user when service is granted and can be used to prepare the environment of child processes run as the authenticated user.

See Context::envlist().

Examples

// Print the PAM environment
for item in &context.envlist() {
    println!("VAR: {}", item);
}

The environment can be passed to std::process::Command by using EnvList::iter_tuples():

use std::process::Command;

// Spawn a process in the PAM environment
let command = Command::new("/usr/bin/some_program")
                      .env_clear()
                      .envs(context.envlist().iter_tuples());

The environment can be passed to NIX’s execve by using EnvList::as_ref():

use nix::unistd::execve;

// Replace this process with another program in the PAM environment
execve(
    &CString::new("/usr/bin/some_program").unwrap(),
    &[CString::new("some_program").unwrap()],
    context.envlist().as_ref()
).expect("replacing the current process failed");

Implementations

Source

impl EnvList

pub fn get<T: AsRef<OsStr>>(&self, name: T) -> Option<&OsStr>

Returns a reference to the value of the named environment variable.

Returns None if the variable doesn’t exist in this list.

pub fn iter(&self) -> Iter<'_>

Returns an iterator over all contained variables as EnvItems.

The iteration happens in deterministic, but unspecified order.

pub fn len(&self) -> usize

Returns the count of environment variables in the list.

pub fn is_empty(&self) -> bool

Returns true if the environment list is empty.

pub fn iter_tuples(&self) -> TupleIter<'_>

Returns an iterator over all contained variables as (key: &OsStr, value: &OsStr) tuples.

The iteration happens in deterministic, but unspecified order.

Provides compatibility with std::process::Command::envs().